@@ -2,8 +2,10 @@ from datetime import datetime
 from datetime import date as Ddate
 from datetime import time as DTime
 
+from web_foundation.workers.web.erorrs.application import InconsistencyError
 
-def string_from_db_date(db_date: datetime | Ddate | DTime, iso_date_format=False):
+
+def string_from_db_date(db_date: datetime | Ddate | DTime | str, iso_date_format=False) -> str:
     v = db_date
     if isinstance(db_date, datetime):
         if iso_date_format:
@@ -17,20 +19,23 @@ def string_from_db_date(db_date: datetime | Ddate | DTime, iso_date_format=False
             v = db_date.strftime("%d.%m.%Y")
     elif isinstance(db_date, DTime):
         v = db_date.replace(microsecond=0).isoformat()
-    return v
+    return str(v)
 
 
-def integrity_error_format(exception) -> str:
+def integrity_error_format(exception) -> InconsistencyError:
     str_exception = str(exception)
-    if "table" in str_exception:
-        # tortoise.exceptions.IntegrityError: insert or update on table "issue"
-        # violates foreign key constraint "issue_service_id_fkey"
+
+    if "table" in str_exception:  # tortoise.exceptions.IntegrityError: insert or update on table "issue" violates foreign key constraint "issue_service_id_fkey"
         start_tablename = str_exception.rfind("table") + 7
         end_tablename = str_exception.rfind(".", start_tablename) - 1
-        return f"Related model {str_exception[start_tablename:end_tablename].capitalize()} not exist"
+        model_name = str_exception[start_tablename:end_tablename].capitalize()
+        return InconsistencyError(
+            message=f"Related model {model_name} not exist")
     elif str_exception.startswith("null"):
         start_field_name = str_exception.find('"') + 1
         end_field_name = str_exception.rfind('"')
-        return f"{str_exception[start_field_name:end_field_name]} can't be null"
+        return InconsistencyError(message=f"{str_exception[start_field_name:end_field_name]} can't be null")
+    elif "already exist" in str_exception:
+        return InconsistencyError(message="Already exist")
     else:
-        return str(exception)
+        return InconsistencyError(exception)
