@@ -1,12 +1,13 @@
 import random
 import string
+from typing import Set
 
 from .singleton import Singleton
 
 
 class NamedObject(Singleton):
     sname: str
-    _named = set()
+    _named: Set[str] = set()
 
     def __new__(cls, *args, **kwargs):
         super(NamedObject, cls).__new__(cls, *args, **kwargs)
