@@ -4,7 +4,7 @@ from typing import Type, TypeVar
 
 from web_foundation.kernel.pyext.named_obj import NamedObject
 
-Obj = TypeVar("Obj")
+Obj = TypeVar("Obj", bound=NamedObject, covariant=True)
 
 
 class IterableNamespace(SimpleNamespace):
@@ -23,6 +23,3 @@ class TypedNamespace(IterableNamespace):
 
     def set_(self, cls: NamedObject):
         setattr(self, cls.sname, cls)
-
-
-
