@@ -1,9 +1,10 @@
 from functools import partial
-from typing import Callable, Coroutine, Tuple, Dict, Any
+from typing import Callable, Tuple, Dict, Any
 
 from web_foundation.kernel import IMessage
+from web_foundation.kernel.isolates.channel import GenericIMessage
 
-BgTask = Callable[[IMessage, ...], Coroutine[Any, Any, IMessage | None]] | partial
+BgTask = Callable[[GenericIMessage], Any] | partial
 
 
 class TaskIMessage(IMessage):
@@ -12,7 +13,8 @@ class TaskIMessage(IMessage):
     kwargs: Dict
     respond: bool
 
-    def __init__(self, destination: str, task: BgTask, args: Tuple = None, kwargs: Dict = None, respond: bool = False):
+    def __init__(self, destination: str, task: BgTask, args: Tuple[Any] = None, kwargs: Dict[Any, Any] = None,
+                 respond: bool = False):
         super().__init__(destination)
         self.task = task
         self.respond = respond
@@ -24,6 +26,6 @@ class TaskReplyIMessage(IMessage):
     response: Any
 
     def __init__(self, task_msg: TaskIMessage, response: Any, sender: str):
-        super().__init__(task_msg.sender, task_msg.index)
+        super().__init__(task_msg.sender, idx=task_msg.index)
         self.response = response
         self.sender = sender
