@@ -2,12 +2,12 @@ import warnings
 from dataclasses import dataclass
 from distutils.version import LooseVersion
 from functools import wraps
-from http.client import HTTPResponse
 from types import MethodType, SimpleNamespace
-from typing import List, Any, Dict, Callable, Type
+from typing import List, Any, Dict, Callable, Type, TypeVar, Generic, ParamSpec, ClassVar
 
+from mypy_extensions import VarArg, KwArg
 from pydantic import BaseModel as PdModel
-from sanic import __version__ as sanic_version, Request, json, text
+from sanic import __version__ as sanic_version, Request, json, text, HTTPResponse
 
 from web_foundation.kernel import class_of_method, NamedContext
 from web_foundation.workers.web.sanic_ext.structs import InputContext, ProtectIdentity, HTTPMethod
@@ -23,21 +23,22 @@ except ImportError:
     use_ext = False
     Extension = object
     from sanic.config import Config
-
 SANIC_VERSION = LooseVersion(sanic_version)
 SANIC_21_9_0 = LooseVersion("21.9.0")
 
+P = ParamSpec("P")
+
 
 class RequestParser:
-    extracted_attrs: List[str]
+    extracted_attrs: List[str] | None
     struct: PdModel | None
-    dto_validation_fnc: Callable[[Request, Type[PdModel]], PdModel]
+    dto_validation_fnc: Callable[..., PdModel]
 
     def __init__(self,
-                 dto_validation_fnc: Callable[[Request, Type[PdModel]], PdModel],
+                 dto_validation_fnc: Callable[..., PdModel],
                  extracted_attrs: List[str] = None,
                  struct: PdModel = None):
-        self.dto_validation_fnc = dto_validation_fnc
+        self.dto_validation_fnc = dto_validation_fnc  # type: ignore
         self.struct = struct
         if extracted_attrs:
             for attr in extracted_attrs:
@@ -58,20 +59,23 @@ class RequestParser:
 
 
 class ResponseConstructor:
-    fabric: Callable[[...], HTTPResponse]
+    fabric: Callable[[Any], HTTPResponse] | None
     default_response: HTTPResponse
-    pd_model: Type[PdModel]
+    pd_model: Type[PdModel] | None
 
     def __init__(self,
                  pd_model: Type[PdModel] = None,
-                 fabric: Callable[[...], HTTPResponse] = None,
-                 default_response: HTTPResponse = None):
+                 fabric: Callable[[Any], HTTPResponse] = None,
+                 default_response: HTTPResponse = text("OK")):
         self.default_response = default_response
         self.pd_model = pd_model
         self.fabric = fabric
 
     def return_(self, to_response: Any) -> HTTPResponse:
-        return self.fabric(to_response) if self.fabric else self.default_response
+        if self.fabric:
+            return self.fabric(to_response)
+        else:
+            return self.default_response
 
 
 class Protector:
@@ -85,17 +89,16 @@ class Protector:
         return None
 
 
-class AbcPipeline:
-    pass
+GenericPipline = TypeVar("GenericPipline")
 
 
 @dataclass()
-class PipelinedRouteConf:
-    pipeline: Type[AbcPipeline] | List[Type[AbcPipeline]] | None
+class PipelinedRouteConf(Generic[GenericPipline]):
+    pipeline: GenericPipline | List[GenericPipline] | None
     uri: str
     method: HTTPMethod
-    target: MethodType
-    protector: Type[Protector]
+    target: Callable[[VarArg(Any), KwArg(Any)], Any]
+    protector: Type[Protector] | None
     kwargs: Dict[str, Any]
 
     def __eq__(self, other):
@@ -105,15 +108,15 @@ class PipelinedRouteConf:
         return f"Route-conf in pipeline {self.pipeline} to {self.uri} {self.method} on {self.target}"
 
 
-class Pipeline(AbcPipeline):
+class Pipeline:
     routes_confs: List[PipelinedRouteConf]
 
     def __str__(self):
-        return ";".join(self.routes_confs)
+        return ";".join(str(self.routes_confs))
 
 
 class PipelinesExt(Extension):
-    name: str = "SanicPipeline"
+    name: str = "pipelines"
     _pipelines: List[Pipeline]
 
     def __init__(self):
@@ -141,16 +144,19 @@ class PipelinesExt(Extension):
                 bootstrap.app.add_route(route_cfg.target, route_cfg.uri, methods=[route_cfg.method.value],
                                         **route_cfg.kwargs)
 
+    def label(self):
+        return f"pipelines added ({', '.join([i.__name__ for i in self._pipelines])})"
+
 
 def set_to_pipline(uri: str,
                    method: HTTPMethod,
-                   pipline: Type[Pipeline] | List[Type[Pipeline]] | None = None,
-                   protector: Type[Protector] = Protector,
-                   struct: PdModel = None,
-                   out_struct: PdModel = None,
+                   pipline: GenericPipline | List[GenericPipline] | None = None,
+                   protector: Type[Protector] | None = Protector,
+                   struct: Type[PdModel] | None = None,
+                   out_struct: Type[PdModel] | None = None,
                    extracted_attrs: List[str] = None,
-                   dto_validation_fnc: Callable[[Request, Type[PdModel]], PdModel] = validate_dto,
-                   return_fabric: Callable[[...], HTTPResponse] = json,
+                   dto_validation_fnc: Callable[..., PdModel] = validate_dto,
+                   return_fabric: Callable[[Any], HTTPResponse] = json,
                    default_response: HTTPResponse = text("ok"),
                    **route_kwargs):
     def called_method(target: MethodType):
@@ -163,7 +169,7 @@ def set_to_pipline(uri: str,
             ret_val = await target(n_ctx.get_obj(class_of_method(target)), incoming, prot_identity)
             return ResponseConstructor(out_struct, return_fabric, default_response).return_(ret_val)
 
-        f.route_conf = PipelinedRouteConf(pipline, uri, method, f, protector, route_kwargs)
+        setattr(f, "route_conf", PipelinedRouteConf(pipline, uri, method, f, protector, route_kwargs))
         return f
 
     return called_method
