@@ -5,7 +5,7 @@ from pydantic import ValidationError as PdValidationError, BaseModel as PdModel
 from .erorrs.application import InconsistencyError
 
 
-def validate_dto(request: Request, dto_cls: Type[PdModel]):
+def validate_dto(request: Request, dto_cls: Type[PdModel]) -> PdModel:
     try:
         dto = dto_cls(**request.json)
         return dto
@@ -16,5 +16,5 @@ def validate_dto(request: Request, dto_cls: Type[PdModel]):
 def dto_validation_error_format(exeption: PdValidationError):
     failed_fields = exeption.errors()
     commment_str = "Some of essential params failed : " + ", ".join(
-        [field["loc"][-1] + " - " + field["msg"] for field in failed_fields])
+        [str(field["loc"][-1]) + " - " + field["msg"] for field in failed_fields])
     return commment_str
